#[repr(u16)]pub enum ColumnFlag {
Nullable = 1,
CaseSensitive = 2,
Updateable = 8,
UpdateableUnknown = 16,
Identity = 32,
Computed = 128,
FixedLenClrType = 1_024,
SparseColumnSet = 2_048,
Encrypted = 4_096,
Hidden = 8_192,
Key = 16_384,
NullableUnknown = 32_768,
}Expand description
A setting a column can hold.
Variants
Nullable = 1
The column can be null.
CaseSensitive = 2
Set for string columns with binary collation and always for the XML data type.
Updateable = 8
If column is writeable.
UpdateableUnknown = 16
Column modification status unknown.
Identity = 32
Column is an identity.
Computed = 128
Coulumn is computed.
FixedLenClrType = 1_024
Column is a fixed-length common language runtime user-defined type (CLR UDT).
SparseColumnSet = 2_048
Column is the special XML column for the sparse column set.
Encrypted = 4_096
Column is encrypted transparently and has to be decrypted to view the plaintext value. This flag is valid when the column encryption feature is negotiated between client and server and is turned on.
Hidden = 8_192
Column is part of a hidden primary key created to support a T-SQL SELECT statement containing FOR BROWSE.
Key = 16_384
Column is part of a primary key for the row and the T-SQL SELECT statement contains FOR BROWSE.
NullableUnknown = 32_768
It is unknown whether the column might be nullable.